@@ -2,6 +2,7 @@
 from ..const import API_PATH
 from .listing.generator import ListingGenerator
 from .base import PRAWBase
+from .util import stream_generator
 
 
 class Inbox(PRAWBase):
@@ -160,7 +161,7 @@ class Inbox(PRAWBase):
         Additional keyword arguments are passed in the initialization of
         :class:`.ListingGenerator`.
 
-        For example, to output the receipient of the mot recent 15 messages
+        For example, to output the recipient of the mot recent 15 messages
         try:
 
         .. code:: python
@@ -172,6 +173,24 @@ class Inbox(PRAWBase):
         return ListingGenerator(self._reddit, API_PATH['sent'],
                                 **generator_kwargs)
 
+    def stream(self, **stream_options):
+        """Yield new inbox items as they become available.
+
+        Items are yielded oldest first. Up to 100 historical items will
+        initially be returned.
+
+        Keyword arguments are passed to :meth:`.stream_generator`.
+
+        For example, to retrieve all new inbox items, try:
+
+        .. code:: python
+
+           for item in reddit.inbox.stream():
+               print(item)
+
+        """
+        return stream_generator(self.unread, **stream_options)
+
     def submission_replies(self, **generator_kwargs):
         """Return a ListingGenerator for submission replies.
 
@@ -192,13 +211,10 @@ class Inbox(PRAWBase):
     def unread(self, mark_read=False, **generator_kwargs):
         """Return a ListingGenerator for unread comments and messages.
 
-        :param mark_read: Marks the messages as read when they're obtained
-            (default: False).
+        :param mark_read: Marks the inbox as read (default: False).
 
-        .. note:: When marking messages as read, the entire batch (up to 100 at
-                  a time) is marked as read when fetched. Failure to consume
-                  the entire listing may result in missed messages if you only
-                  obtain unread messages.
+        .. note:: This only marks the inbox as read not the messages. Use
+                  :meth:`.Inbox.mark_read` to mark the messages.
 
         Additional keyword arguments are passed in the initialization of
         :class:`.ListingGenerator`.
@@ -213,6 +229,7 @@ class Inbox(PRAWBase):
                    print(item.author)
 
         """
-        params = {'mark': mark_read}
+        self._safely_add_arguments(
+            generator_kwargs, 'params', mark=mark_read)
         return ListingGenerator(self._reddit, API_PATH['unread'],
-                                params=params, **generator_kwargs)
+                                **generator_kwargs)
