@@ -43,7 +43,7 @@ class Submission(RedditBase, SubmissionListingMixin, UserContentMixin):
 
     @property
     def comments(self):
-        """An instance of :class:`.CommentForest`.
+        """Provide an instance of :class:`.CommentForest`.
 
         This attribute can use used, for example, to obtain a flat list of
         comments, with any :class:`.MoreComments` removed:
@@ -53,6 +53,15 @@ class Submission(RedditBase, SubmissionListingMixin, UserContentMixin):
            submission.comments.replace_more(limit=0)
            comments = submission.comments.list()
 
+        Sort order and comment limit can be set with the ``comment_sort`` and
+        ``comment_limit`` attributes before comments are fetched, including
+        any call to :meth:`.replace_more`:
+
+        .. code:: python
+
+           submission.comment_sort = 'new'
+           comments = submission.comments.list()
+
         See :ref:`extracting_comments` for more on working with a
         :class:`.CommentForest`.
 
@@ -62,7 +71,7 @@ class Submission(RedditBase, SubmissionListingMixin, UserContentMixin):
 
     @property
     def flair(self):
-        """An instance of :class:`.SubmissionFlair`.
+        """Provide an instance of :class:`.SubmissionFlair`.
 
         This attribute is used to work with flair as a regular user of the
         subreddit the submission belongs to. Moderators can directly use
@@ -85,7 +94,7 @@ class Submission(RedditBase, SubmissionListingMixin, UserContentMixin):
 
     @property
     def mod(self):
-        """An instance of :class:`.SubmissionModeration`."""
+        """Provide an instance of :class:`.SubmissionModeration`."""
         if self._mod is None:
             self._mod = SubmissionModeration(self)
         return self._mod
@@ -127,11 +136,21 @@ class Submission(RedditBase, SubmissionListingMixin, UserContentMixin):
             value = Subreddit(self._reddit, value)
         super(Submission, self).__setattr__(attribute, value)
 
+    def _chunk(self, other_submissions, chunk_size):
+        all_submissions = [self.fullname]
+        if other_submissions:
+            all_submissions += [x.fullname for x in other_submissions]
+
+        for position in range(0, len(all_submissions), chunk_size):
+            yield ','.join(all_submissions[position:position + 50])
+
     def _fetch(self):
         other, comments = self._reddit.get(self._info_path(),
                                            params={'limit': self.comment_limit,
                                                    'sort': self.comment_sort})
         other = other.children[0]
+        delattr(other, 'comment_limit')
+        delattr(other, 'comment_sort')
         other._comments = CommentForest(self)
         self.__dict__.update(other.__dict__)
         self.comments._update(comments.children)
@@ -148,12 +167,8 @@ class Submission(RedditBase, SubmissionListingMixin, UserContentMixin):
             as part of a single request (default: None).
 
         """
-        if other_submissions:
-            submissions = ','.join([self.fullname] +
-                                   [x.fullname for x in other_submissions])
-        else:
-            submissions = self.fullname
-        self._reddit.post(API_PATH['hide'], data={'id': submissions})
+        for submissions in self._chunk(other_submissions, 50):
+            self._reddit.post(API_PATH['hide'], data={'id': submissions})
 
     @property
     def shortlink(self):
@@ -173,12 +188,8 @@ class Submission(RedditBase, SubmissionListingMixin, UserContentMixin):
             as part of a single request (default: None).
 
         """
-        if other_submissions:
-            submissions = ','.join([self.fullname] +
-                                   [x.fullname for x in other_submissions])
-        else:
-            submissions = self.fullname
-        self._reddit.post(API_PATH['unhide'], data={'id': submissions})
+        for submissions in self._chunk(other_submissions, 50):
+            self._reddit.post(API_PATH['unhide'], data={'id': submissions})
 
 
 class SubmissionFlair(object):
@@ -233,8 +244,7 @@ class SubmissionFlair(object):
                 'link': self.submission.fullname, 'text': text}
         url = API_PATH['select_flair'].format(
             subreddit=self.submission.subreddit)
-        # PRAW5 REMOVE (return statement)
-        return self.submission._reddit.post(url, data=data)
+        self.submission._reddit.post(url, data=data)
 
 
 class SubmissionModeration(ThingModerationMixin):
